@@ -23,14 +23,12 @@
 #include "Category.h"
 #include "CategoriesReader.h"
 
-// KDE includes
-#include <KCategorizedSortFilterProxyModel>
-
-Q_GLOBAL_STATIC_WITH_ARGS(QList<Category*>, s_categories, (CategoriesReader().populateCategories()))
+Q_GLOBAL_STATIC_WITH_ARGS(QVector<Category*>, s_categories, (CategoriesReader().populateCategories()))
 
 CategoryModel::CategoryModel(QObject* parent)
     : QStandardItemModel(parent)
     , m_currentCategory(nullptr)
+    , m_filter(ShowEverything)
 {
 }
 
@@ -41,17 +39,20 @@ QHash< int, QByteArray > CategoryModel::roleNames() const
     return names;
 }
 
-void CategoryModel::setCategories(const QList<Category *> &categoryList, const QString &rootName)
+void CategoryModel::setCategories(const QVector<Category *> &categoryList)
 {
     clear();
 
     invisibleRootItem()->removeRows(0, invisibleRootItem()->rowCount());
     foreach (Category *category, categoryList) {
+        if (m_filter != ShowEverything && (category->isAddons() != (m_filter == OnlyAddons))) {
+            continue;
+        }
+
         QStandardItem *categoryItem = new QStandardItem;
         categoryItem->setText(category->name());
         categoryItem->setIcon(QIcon::fromTheme(category->icon()));
         categoryItem->setEditable(false);
-        categoryItem->setData(rootName, KCategorizedSortFilterProxyModel::CategoryDisplayRole);
         categoryItem->setData(qVariantFromValue<QObject*>(category), CategoryRole);
         connect(category, &QObject::destroyed, this, &CategoryModel::categoryDeleted);
 
@@ -79,12 +80,9 @@ void CategoryModel::setDisplayedCategory(Category* c)
         return;
 
     m_currentCategory = c;
-    if(c)
-        setCategories(c->subCategories(), c->name());
-    else
-        setCategories(*s_categories, QString());
+    resetCategories();
 
-    categoryChanged(c);
+    Q_EMIT categoryChanged(c);
 }
 
 Category* CategoryModel::displayedCategory() const
@@ -96,8 +94,8 @@ static Category* recFindCategory(Category* root, const QString& name)
 {
     if(root->name()==name)
         return root;
-    else if(root->hasSubCategories()) {
-        const QList<Category*> subs = root->subCategories();
+    else {
+        const QVector<Category*> subs = root->subCategories();
         Q_FOREACH (Category* c, subs) {
             Category* ret = recFindCategory(c, name);
             if(ret)
@@ -109,7 +107,7 @@ static Category* recFindCategory(Category* root, const QString& name)
 
 Category* CategoryModel::findCategoryByName(const QString& name)
 {
-    const QList<Category*> cats = *s_categories;
+    const QVector<Category*> cats = *s_categories;
     Q_FOREACH (Category* cat, cats) {
         Category* ret = recFindCategory(cat, name);
         if(ret)
@@ -121,7 +119,7 @@ Category* CategoryModel::findCategoryByName(const QString& name)
 void CategoryModel::blacklistPlugin(const QString& name)
 {
     const QSet<QString> plugins = {name};
-    for(QList<Category*>::iterator it = s_categories->begin(), itEnd = s_categories->end(); it!=itEnd; ) {
+    for(auto it = s_categories->begin(), itEnd = s_categories->end(); it!=itEnd; ) {
         if ((*it)->blacklistPlugins(plugins)) {
             delete *it;
             it = s_categories->erase(it);
@@ -129,3 +127,22 @@ void CategoryModel::blacklistPlugin(const QString& name)
             ++it;
     }
 }
+
+CategoryModel::ShowAddons CategoryModel::filter() const
+{
+    return m_filter;
+}
+
+void CategoryModel::setFilter(CategoryModel::ShowAddons filter)
+{
+    m_filter = filter;
+    resetCategories();
+}
+
+void CategoryModel::resetCategories()
+{
+    if(m_currentCategory)
+        setCategories(m_currentCategory->subCategories());
+    else
+        setCategories(*s_categories);
+}
