@@ -88,7 +88,6 @@ void UpdateModel::activityChanged()
         setResources(QList<AbstractResource*>());
     } else if(!m_updates->isProgressing()) {
         m_updates->prepare();
-        m_updates->fetchChangelog();
         setResources(m_updates->toUpdate());
     }
 }
@@ -166,6 +165,15 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
     return false;
 }
 
+void UpdateModel::fetchChangelog(int row)
+{
+    UpdateItem *item = itemFromIndex(index(row, 0));
+    Q_ASSERT(item);
+    if (!item) return;
+
+    item->app()->fetchChangelog();
+}
+
 void UpdateModel::integrateChangelog(const QString &changelog)
 {
     auto app = qobject_cast<AbstractResource*>(sender());
